@@ -8,6 +8,7 @@ from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.list_jobs_response_200_item_type_0 import ListJobsResponse200ItemType0
 from ...models.list_jobs_response_200_item_type_1 import ListJobsResponse200ItemType1
+from ...models.list_jobs_trigger_kind import ListJobsTriggerKind
 from ...types import UNSET, Response, Unset
 
 
@@ -39,6 +40,7 @@ def _get_kwargs(
     result: Union[Unset, None, str] = UNSET,
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -131,6 +133,12 @@ def _get_kwargs(
 
     params["per_page"] = per_page
 
+    json_trigger_kind: Union[Unset, None, str] = UNSET
+    if not isinstance(trigger_kind, Unset):
+        json_trigger_kind = trigger_kind.value if trigger_kind else None
+
+    params["trigger_kind"] = json_trigger_kind
+
     params["is_skipped"] = is_skipped
 
     params["is_flow_step"] = is_flow_step
@@ -230,6 +238,7 @@ def sync_detailed(
     result: Union[Unset, None, str] = UNSET,
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -266,6 +275,7 @@ def sync_detailed(
         result (Union[Unset, None, str]):
         allow_wildcards (Union[Unset, None, bool]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -308,6 +318,7 @@ def sync_detailed(
         result=result,
         allow_wildcards=allow_wildcards,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -352,6 +363,7 @@ def sync(
     result: Union[Unset, None, str] = UNSET,
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -388,6 +400,7 @@ def sync(
         result (Union[Unset, None, str]):
         allow_wildcards (Union[Unset, None, bool]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -431,6 +444,7 @@ def sync(
         result=result,
         allow_wildcards=allow_wildcards,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -469,6 +483,7 @@ async def asyncio_detailed(
     result: Union[Unset, None, str] = UNSET,
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -505,6 +520,7 @@ async def asyncio_detailed(
         result (Union[Unset, None, str]):
         allow_wildcards (Union[Unset, None, bool]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -547,6 +563,7 @@ async def asyncio_detailed(
         result=result,
         allow_wildcards=allow_wildcards,
         per_page=per_page,
+        trigger_kind=trigger_kind,
         is_skipped=is_skipped,
         is_flow_step=is_flow_step,
         has_null_parent=has_null_parent,
@@ -589,6 +606,7 @@ async def asyncio(
     result: Union[Unset, None, str] = UNSET,
     allow_wildcards: Union[Unset, None, bool] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
+    trigger_kind: Union[Unset, None, ListJobsTriggerKind] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
     is_flow_step: Union[Unset, None, bool] = UNSET,
     has_null_parent: Union[Unset, None, bool] = UNSET,
@@ -625,6 +643,7 @@ async def asyncio(
         result (Union[Unset, None, str]):
         allow_wildcards (Union[Unset, None, bool]):
         per_page (Union[Unset, None, int]):
+        trigger_kind (Union[Unset, None, ListJobsTriggerKind]):
         is_skipped (Union[Unset, None, bool]):
         is_flow_step (Union[Unset, None, bool]):
         has_null_parent (Union[Unset, None, bool]):
@@ -669,6 +688,7 @@ async def asyncio(
             result=result,
             allow_wildcards=allow_wildcards,
             per_page=per_page,
+            trigger_kind=trigger_kind,
             is_skipped=is_skipped,
             is_flow_step=is_flow_step,
             has_null_parent=has_null_parent,
