@@ -7,6 +7,10 @@ from ..models.get_app_by_path_response_200_policy_execution_mode import GetAppBy
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.get_app_by_path_response_200_policy_allowed_s3_keys_item import (
+        GetAppByPathResponse200PolicyAllowedS3KeysItem,
+    )
+    from ..models.get_app_by_path_response_200_policy_s3_inputs_item import GetAppByPathResponse200PolicyS3InputsItem
     from ..models.get_app_by_path_response_200_policy_triggerables import GetAppByPathResponse200PolicyTriggerables
     from ..models.get_app_by_path_response_200_policy_triggerables_v2 import GetAppByPathResponse200PolicyTriggerablesV2
 
@@ -20,6 +24,8 @@ class GetAppByPathResponse200Policy:
     Attributes:
         triggerables (Union[Unset, GetAppByPathResponse200PolicyTriggerables]):
         triggerables_v2 (Union[Unset, GetAppByPathResponse200PolicyTriggerablesV2]):
+        s3_inputs (Union[Unset, List['GetAppByPathResponse200PolicyS3InputsItem']]):
+        allowed_s3_keys (Union[Unset, List['GetAppByPathResponse200PolicyAllowedS3KeysItem']]):
         execution_mode (Union[Unset, GetAppByPathResponse200PolicyExecutionMode]):
         on_behalf_of (Union[Unset, str]):
         on_behalf_of_email (Union[Unset, str]):
@@ -27,6 +33,8 @@ class GetAppByPathResponse200Policy:
 
     triggerables: Union[Unset, "GetAppByPathResponse200PolicyTriggerables"] = UNSET
     triggerables_v2: Union[Unset, "GetAppByPathResponse200PolicyTriggerablesV2"] = UNSET
+    s3_inputs: Union[Unset, List["GetAppByPathResponse200PolicyS3InputsItem"]] = UNSET
+    allowed_s3_keys: Union[Unset, List["GetAppByPathResponse200PolicyAllowedS3KeysItem"]] = UNSET
     execution_mode: Union[Unset, GetAppByPathResponse200PolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
@@ -41,6 +49,22 @@ class GetAppByPathResponse200Policy:
         if not isinstance(self.triggerables_v2, Unset):
             triggerables_v2 = self.triggerables_v2.to_dict()
 
+        s3_inputs: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.s3_inputs, Unset):
+            s3_inputs = []
+            for s3_inputs_item_data in self.s3_inputs:
+                s3_inputs_item = s3_inputs_item_data.to_dict()
+
+                s3_inputs.append(s3_inputs_item)
+
+        allowed_s3_keys: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.allowed_s3_keys, Unset):
+            allowed_s3_keys = []
+            for allowed_s3_keys_item_data in self.allowed_s3_keys:
+                allowed_s3_keys_item = allowed_s3_keys_item_data.to_dict()
+
+                allowed_s3_keys.append(allowed_s3_keys_item)
+
         execution_mode: Union[Unset, str] = UNSET
         if not isinstance(self.execution_mode, Unset):
             execution_mode = self.execution_mode.value
@@ -55,6 +79,10 @@ class GetAppByPathResponse200Policy:
             field_dict["triggerables"] = triggerables
         if triggerables_v2 is not UNSET:
             field_dict["triggerables_v2"] = triggerables_v2
+        if s3_inputs is not UNSET:
+            field_dict["s3_inputs"] = s3_inputs
+        if allowed_s3_keys is not UNSET:
+            field_dict["allowed_s3_keys"] = allowed_s3_keys
         if execution_mode is not UNSET:
             field_dict["execution_mode"] = execution_mode
         if on_behalf_of is not UNSET:
@@ -66,6 +94,12 @@ class GetAppByPathResponse200Policy:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.get_app_by_path_response_200_policy_allowed_s3_keys_item import (
+            GetAppByPathResponse200PolicyAllowedS3KeysItem,
+        )
+        from ..models.get_app_by_path_response_200_policy_s3_inputs_item import (
+            GetAppByPathResponse200PolicyS3InputsItem,
+        )
         from ..models.get_app_by_path_response_200_policy_triggerables import GetAppByPathResponse200PolicyTriggerables
         from ..models.get_app_by_path_response_200_policy_triggerables_v2 import (
             GetAppByPathResponse200PolicyTriggerablesV2,
@@ -86,6 +120,20 @@ class GetAppByPathResponse200Policy:
         else:
             triggerables_v2 = GetAppByPathResponse200PolicyTriggerablesV2.from_dict(_triggerables_v2)
 
+        s3_inputs = []
+        _s3_inputs = d.pop("s3_inputs", UNSET)
+        for s3_inputs_item_data in _s3_inputs or []:
+            s3_inputs_item = GetAppByPathResponse200PolicyS3InputsItem.from_dict(s3_inputs_item_data)
+
+            s3_inputs.append(s3_inputs_item)
+
+        allowed_s3_keys = []
+        _allowed_s3_keys = d.pop("allowed_s3_keys", UNSET)
+        for allowed_s3_keys_item_data in _allowed_s3_keys or []:
+            allowed_s3_keys_item = GetAppByPathResponse200PolicyAllowedS3KeysItem.from_dict(allowed_s3_keys_item_data)
+
+            allowed_s3_keys.append(allowed_s3_keys_item)
+
         _execution_mode = d.pop("execution_mode", UNSET)
         execution_mode: Union[Unset, GetAppByPathResponse200PolicyExecutionMode]
         if isinstance(_execution_mode, Unset):
@@ -100,6 +148,8 @@ class GetAppByPathResponse200Policy:
         get_app_by_path_response_200_policy = cls(
             triggerables=triggerables,
             triggerables_v2=triggerables_v2,
+            s3_inputs=s3_inputs,
+            allowed_s3_keys=allowed_s3_keys,
             execution_mode=execution_mode,
             on_behalf_of=on_behalf_of,
             on_behalf_of_email=on_behalf_of_email,
