@@ -55,6 +55,8 @@ class GetScheduleResponse200:
         tag (Union[Unset, str]):
         paused_until (Union[Unset, datetime.datetime]):
         cron_version (Union[Unset, str]):
+        dynamic_skip (Union[Unset, str]): Path to a script that validates scheduled datetimes. Receives scheduled_for
+            datetime and returns boolean.
     """
 
     path: str
@@ -86,6 +88,7 @@ class GetScheduleResponse200:
     tag: Union[Unset, str] = UNSET
     paused_until: Union[Unset, datetime.datetime] = UNSET
     cron_version: Union[Unset, str] = UNSET
+    dynamic_skip: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -138,6 +141,7 @@ class GetScheduleResponse200:
             paused_until = self.paused_until.isoformat()
 
         cron_version = self.cron_version
+        dynamic_skip = self.dynamic_skip
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -193,6 +197,8 @@ class GetScheduleResponse200:
             field_dict["paused_until"] = paused_until
         if cron_version is not UNSET:
             field_dict["cron_version"] = cron_version
+        if dynamic_skip is not UNSET:
+            field_dict["dynamic_skip"] = dynamic_skip
 
         return field_dict
 
@@ -294,6 +300,8 @@ class GetScheduleResponse200:
 
         cron_version = d.pop("cron_version", UNSET)
 
+        dynamic_skip = d.pop("dynamic_skip", UNSET)
+
         get_schedule_response_200 = cls(
             path=path,
             edited_by=edited_by,
@@ -324,6 +332,7 @@ class GetScheduleResponse200:
             tag=tag,
             paused_until=paused_until,
             cron_version=cron_version,
+            dynamic_skip=dynamic_skip,
         )
 
         get_schedule_response_200.additional_properties = d
