@@ -47,6 +47,8 @@ class GetScriptByPathWithDraftResponse200:
         delete_after_use (Union[Unset, bool]):
         deployment_message (Union[Unset, str]):
         concurrency_key (Union[Unset, str]):
+        debounce_key (Union[Unset, str]):
+        debounce_delay_s (Union[Unset, int]):
         visible_to_runner_only (Union[Unset, bool]):
         no_main_func (Union[Unset, bool]):
         codebase (Union[Unset, str]):
@@ -81,6 +83,8 @@ class GetScriptByPathWithDraftResponse200:
     delete_after_use: Union[Unset, bool] = UNSET
     deployment_message: Union[Unset, str] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
+    debounce_key: Union[Unset, str] = UNSET
+    debounce_delay_s: Union[Unset, int] = UNSET
     visible_to_runner_only: Union[Unset, bool] = UNSET
     no_main_func: Union[Unset, bool] = UNSET
     codebase: Union[Unset, str] = UNSET
@@ -126,6 +130,8 @@ class GetScriptByPathWithDraftResponse200:
         delete_after_use = self.delete_after_use
         deployment_message = self.deployment_message
         concurrency_key = self.concurrency_key
+        debounce_key = self.debounce_key
+        debounce_delay_s = self.debounce_delay_s
         visible_to_runner_only = self.visible_to_runner_only
         no_main_func = self.no_main_func
         codebase = self.codebase
@@ -193,6 +199,10 @@ class GetScriptByPathWithDraftResponse200:
             field_dict["deployment_message"] = deployment_message
         if concurrency_key is not UNSET:
             field_dict["concurrency_key"] = concurrency_key
+        if debounce_key is not UNSET:
+            field_dict["debounce_key"] = debounce_key
+        if debounce_delay_s is not UNSET:
+            field_dict["debounce_delay_s"] = debounce_delay_s
         if visible_to_runner_only is not UNSET:
             field_dict["visible_to_runner_only"] = visible_to_runner_only
         if no_main_func is not UNSET:
@@ -279,6 +289,10 @@ class GetScriptByPathWithDraftResponse200:
 
         concurrency_key = d.pop("concurrency_key", UNSET)
 
+        debounce_key = d.pop("debounce_key", UNSET)
+
+        debounce_delay_s = d.pop("debounce_delay_s", UNSET)
+
         visible_to_runner_only = d.pop("visible_to_runner_only", UNSET)
 
         no_main_func = d.pop("no_main_func", UNSET)
@@ -329,6 +343,8 @@ class GetScriptByPathWithDraftResponse200:
             delete_after_use=delete_after_use,
             deployment_message=deployment_message,
             concurrency_key=concurrency_key,
+            debounce_key=debounce_key,
+            debounce_delay_s=debounce_delay_s,
             visible_to_runner_only=visible_to_runner_only,
             no_main_func=no_main_func,
             codebase=codebase,
