@@ -36,6 +36,7 @@ class NewHttpTrigger:
         is_async (Union[Unset, bool]): Deprecated, use request_type instead
         request_type (Union[Unset, NewHttpTriggerRequestType]):
         wrap_body (Union[Unset, bool]):
+        enabled (Union[Unset, bool]):
         raw_string (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
         error_handler_args (Union[Unset, NewHttpTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
@@ -57,6 +58,7 @@ class NewHttpTrigger:
     is_async: Union[Unset, bool] = UNSET
     request_type: Union[Unset, NewHttpTriggerRequestType] = UNSET
     wrap_body: Union[Unset, bool] = UNSET
+    enabled: Union[Unset, bool] = UNSET
     raw_string: Union[Unset, bool] = UNSET
     error_handler_path: Union[Unset, str] = UNSET
     error_handler_args: Union[Unset, "NewHttpTriggerErrorHandlerArgs"] = UNSET
@@ -87,6 +89,7 @@ class NewHttpTrigger:
             request_type = self.request_type.value
 
         wrap_body = self.wrap_body
+        enabled = self.enabled
         raw_string = self.raw_string
         error_handler_path = self.error_handler_path
         error_handler_args: Union[Unset, Dict[str, Any]] = UNSET
@@ -126,6 +129,8 @@ class NewHttpTrigger:
             field_dict["request_type"] = request_type
         if wrap_body is not UNSET:
             field_dict["wrap_body"] = wrap_body
+        if enabled is not UNSET:
+            field_dict["enabled"] = enabled
         if raw_string is not UNSET:
             field_dict["raw_string"] = raw_string
         if error_handler_path is not UNSET:
@@ -184,6 +189,8 @@ class NewHttpTrigger:
 
         wrap_body = d.pop("wrap_body", UNSET)
 
+        enabled = d.pop("enabled", UNSET)
+
         raw_string = d.pop("raw_string", UNSET)
 
         error_handler_path = d.pop("error_handler_path", UNSET)
@@ -218,6 +225,7 @@ class NewHttpTrigger:
             is_async=is_async,
             request_type=request_type,
             wrap_body=wrap_body,
+            enabled=enabled,
             raw_string=raw_string,
             error_handler_path=error_handler_path,
             error_handler_args=error_handler_args,
