@@ -8,6 +8,7 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.update_schedule_json_body_retry_constant import UpdateScheduleJsonBodyRetryConstant
     from ..models.update_schedule_json_body_retry_exponential import UpdateScheduleJsonBodyRetryExponential
+    from ..models.update_schedule_json_body_retry_retry_if import UpdateScheduleJsonBodyRetryRetryIf
 
 
 T = TypeVar("T", bound="UpdateScheduleJsonBodyRetry")
@@ -20,10 +21,12 @@ class UpdateScheduleJsonBodyRetry:
     Attributes:
         constant (Union[Unset, UpdateScheduleJsonBodyRetryConstant]):
         exponential (Union[Unset, UpdateScheduleJsonBodyRetryExponential]):
+        retry_if (Union[Unset, UpdateScheduleJsonBodyRetryRetryIf]):
     """
 
     constant: Union[Unset, "UpdateScheduleJsonBodyRetryConstant"] = UNSET
     exponential: Union[Unset, "UpdateScheduleJsonBodyRetryExponential"] = UNSET
+    retry_if: Union[Unset, "UpdateScheduleJsonBodyRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -35,6 +38,10 @@ class UpdateScheduleJsonBodyRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -42,6 +49,8 @@ class UpdateScheduleJsonBodyRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -49,6 +58,7 @@ class UpdateScheduleJsonBodyRetry:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.update_schedule_json_body_retry_constant import UpdateScheduleJsonBodyRetryConstant
         from ..models.update_schedule_json_body_retry_exponential import UpdateScheduleJsonBodyRetryExponential
+        from ..models.update_schedule_json_body_retry_retry_if import UpdateScheduleJsonBodyRetryRetryIf
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -65,9 +75,17 @@ class UpdateScheduleJsonBodyRetry:
         else:
             exponential = UpdateScheduleJsonBodyRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, UpdateScheduleJsonBodyRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = UpdateScheduleJsonBodyRetryRetryIf.from_dict(_retry_if)
+
         update_schedule_json_body_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         update_schedule_json_body_retry.additional_properties = d
